@@ -3,64 +3,10 @@
 import time
 import threading
 import copy
-import sys
-import json
 from collections import OrderedDict
 
 from .utils import *
 
-# states
-off = 0
-Off = 0
-on = 1
-On = 1
-
-### general utility functions ###
-
-# turn an item into a list if it is not already
-def listize(x):
-    return x if isinstance(x, list) else [x]
-
-# normalize state values from boolean to integers
-def normalState(value):
-    if value == True: return On
-    elif value == False: return Off
-    else: return value
-
-# Compare two state dictionaries and return a dictionary containing the items
-# whose values don't match or aren't in the old dict.
-# If an item is in the old but not in the new, optionally include the item with value None.
-def diffStates(old, new, deleted=True):
-    diff = copy.copy(new)
-    for key in list(old.keys()):
-        try:
-            if new[key] == old[key]:
-                del diff[key]   # values match
-        except KeyError:        # item is missing from the new dict
-            if deleted:         # include deleted item in output
-                diff[key] = None
-    return diff
-
-# create a Resource from a serialized dict
-def loadResource(classDict, globalDict):
-    def parseClass(classDict):
-        args = classDict["args"]
-        argStr = ""
-        for arg in list(args.keys()):
-            argStr += arg+"="
-            if isinstance(args[arg], dict):     # argument is a class
-                argStr += parseClass(args[arg])+", "
-            elif isinstance(args[arg], str):    # arg is a string
-                argStr += "'"+args[arg]+"', "
-            elif not arg:                       # arg is None
-                argStr += "None"
-            else:                               # arg is numeric or other
-                argStr += str(args[arg])+", "
-        return classDict["class"]+"("+argStr[:-2]+")"
-    localDict = {}
-    exec("resource = "+parseClass(classDict), globalDict, localDict)
-    return localDict["resource"]
-
 # Base class for everything
 class Object(object):
     def __init__(self):
@@ -297,7 +243,7 @@ class Collection(Resource, OrderedDict):
 # The state is associated with a unique address on an interface.
 # Sensors can also optionally be associated with a group and a physical location.
 class Sensor(Resource):
-    def __init__(self, name, interface=None, addr=None, type="sensor",
+    def __init__(self, name, interface=None, addr=None, type=None, style="sensor",
                  factor=1, offset=0, resolution=0,
                  poll=10, event=None, persistence=None, interrupt=None,
                  location=None, group="", label=None):
@@ -305,6 +251,8 @@ class Sensor(Resource):
             if self.type:   # init has already been called for this object - FIXME
                 return
         except AttributeError:
+            if not type:
+                type = style
             Resource.__init__(self, name, type)
             self.interface = interface
             self.addr = addr
@@ -327,7 +275,7 @@ class Sensor(Resource):
             if label:
                 self.label = label
             else:
-                self.label = self.name.capitalize()
+                self.label = labelize(self.name)
             self.__dict__["state"] = None   # dummy class variable so hasattr() returns True
             # FIXME - use @property
 
@@ -382,8 +330,8 @@ class Sensor(Resource):
 
 # A Control is a Sensor whose state can be set
 class Control(Sensor):
-    def __init__(self, name, interface=None, addr=None, type="control", stateSet=None, **kwargs):
-        Sensor.__init__(self, name, interface=interface, addr=addr, type=type, **kwargs)
+    def __init__(self, name, interface=None, addr=None, type=None, style="control", stateSet=None, **kwargs):
+        Sensor.__init__(self, name, interface=interface, addr=addr, type=type, style=style, **kwargs)
         self.stateSet = stateSet  # optional callback when state is set
 
     # Set the state of the control by writing the value to the address on the interface.
