@@ -1,14 +1,14 @@
 # initialize the global variables that define the environment
 import os
 import socket
+import sys
 
 # network
 hostname = socket.gethostname()
 localController = "localhost"
 
 # directory structure
-rootDir = ""        # directory containing this application
-# rootDir = os.path.expanduser("~")+"/"
+rootDir = sys.path[0]+"/"        # directory containing this application
 keyDir = rootDir+"keys/"
 stateDir = rootDir+"state/"
 soundDir = rootDir+"sounds/"
@@ -26,5 +26,5 @@ tempScale = "F"
 # optionally import local variables
 try:
     from conf import *
-except ModuleNotFoundError:
+except ImportError:
     pass
